<?php
/*
Plugin Name: KW Command
Description: View website activity in KW Command
Author: BRANDco.
Author URI: https://brandco.com
Version: 2.1.0
License: GPLv2 or later
*/

require plugin_dir_path(__FILE__) . 'vendor/autoload.php';

define('KW_COMMAND_PLUGIN_VERSION', '2.1.0');
define('KW_COMMAND_PLUGIN_DIR_URL', plugin_dir_url(__FILE__));
define('KW_COMMAND_PLUGIN_REMOTE_INFO', 'https://hellobrandco.github.io/kw-command-plugin/plugin-info.json');
define('KW_COMMAND_PLUGIN_REMOTE_DOWNLOAD', 'https://hellobrandco.github.io/kw-command-plugin/kw-command.zip');

if ( !defined('KW_COMMAND_PLUGIN_ENDPOINT') ) {
	define('KW_COMMAND_PLUGIN_ENDPOINT', 'https://partners.api.kw.com');
}

if ( !defined('WP_ENV') ) {
	define('WP_ENV', 'live');
}

register_activation_hook(__FILE__, array('BrandCo\Plugins\KWCommand\Database', 'install_visitors_table'));
register_activation_hook(__FILE__, array('BrandCo\Plugins\KWCommand\Database', 'install_activity_table'));
register_activation_hook(__FILE__, array('BrandCo\Plugins\KWCommand\Cron', 'install'));
add_filter('cron_schedules', array('BrandCo\Plugins\KWCommand\Cron', 'register_interval'));

register_deactivation_hook(__FILE__, array('BrandCo\Plugins\KWCommand\Cron', 'uninstall'));

if ( WP_ENV == 'live' ) {
	add_filter('plugins_api', array('BrandCo\Plugins\KWCommand\Updater', 'info'), 20, 3);
	add_filter('site_transient_update_plugins', array('BrandCo\Plugins\KWCommand\Updater', 'update'));
	add_action('upgrader_process_complete', array('BrandCo\Plugins\KWCommand\Updater', 'after_update'), 10, 2);
}

add_action('visitoractivity/events/after_activity_add', array('BrandCo\Plugins\KWCommand\KWCommand', 'send_activity'), 10, 4);

add_action('wp_enqueue_scripts', array('BrandCo\Plugins\KWCommand\Javascript', 'enqueue'));

add_action('wp_ajax_' . 'kwcmd_log_activity', array('BrandCo\Plugins\KWCommand\Ajax', 'log_activity'));
add_action('wp_ajax_nopriv_' . 'kwcmd_log_activity', array('BrandCo\Plugins\KWCommand\Ajax', 'log_activity'));
add_action('wp_ajax_' . 'kwcmd_identify_user', array('BrandCo\Plugins\KWCommand\Ajax', 'identify_user'));
add_action('wp_ajax_nopriv_' . 'kwcmd_identify_user', array('BrandCo\Plugins\KWCommand\Ajax', 'identify_user'));
add_action('wp_ajax_' . 'kw_api_ping', array('BrandCo\Plugins\KWCommand\Ajax', 'kw_api_ping'));
add_action('wp_ajax_nopriv_' . 'kw_api_ping', array('BrandCo\Plugins\KWCommand\Ajax', 'kw_api_ping'));
add_action('wp_ajax_' . 'refresh_kw_auth', array('BrandCo\Plugins\KWCommand\Ajax', 'refresh_kw_auth'));
add_action('wp_ajax_nopriv_' . 'refresh_kw_auth', array('BrandCo\Plugins\KWCommand\Ajax', 'refresh_kw_auth'));
add_action('wp_ajax_' . 'disconnect_kw_auth', array('BrandCo\Plugins\KWCommand\Ajax', 'disconnect_kw_auth'));
add_action('wp_ajax_nopriv_' . 'disconnect_kw_auth', array('BrandCo\Plugins\KWCommand\Ajax', 'disconnect_kw_auth'));

add_action('rest_api_init', array('BrandCo\Plugins\KWCommand\RestAPI', 'register'), 10, 1);

add_action('template_redirect', array('BrandCo\Plugins\KWCommand\Cookie', 'get_or_set'));
add_action('admin_menu', array('BrandCo\Plugins\KWCommand\Settings', 'add_options_page'));

add_action('visitor_activity_auth', array('BrandCo\Plugins\KWCommand\KWCommandAuth', 'refresh'), 10, 1);
add_action('visitor_database_cleanup', array('BrandCo\Plugins\KWCommand\Activity', 'delete_old_exported_activities'), 10, 1);
add_action('visitor_activity_cron', array('BrandCo\Plugins\KWCommand\KWCommand', 'send_unexported_activity'), 10, 1);

if ( class_exists('GFForms') ) {
	add_action('gform_field_standard_settings', array('BrandCo\Plugins\KWCommand\GravityForms', 'add_dropdown_field'), 10, 2);
	add_action('gform_editor_js', array('BrandCo\Plugins\KWCommand\GravityForms', 'editor_script'));
	add_filter('gform_tooltips', array('BrandCo\Plugins\KWCommand\GravityForms', 'add_tooltip'));
	add_action('gform_after_submission', array('BrandCo\Plugins\KWCommand\GravityForms', 'after_submission'), 10, 2);
}

if ( class_exists('WPCF7_ContactForm') ) {
	add_filter('wpcf7_mail_sent', array('BrandCo\Plugins\KWCommand\ContactForms7', 'after_submit'), 10, 1);
}

add_action('elementor_pro/forms/process', array('BrandCo\Plugins\KWCommand\ElementorForms', 'after_submit'), 1000, 2);

add_filter('allowed_http_origins', array('BrandCo\Plugins\KWCommand\Ajax', 'add_allowed_origins'));
