<?php
namespace BrandCo\Plugins\KWCommand;

class Activity {

	public static function save($visitor_id, $type, $data) {
		global $wpdb;
		$data = serialize(json_encode(json_decode(html_entity_decode(stripslashes($data)))));

		$wpdb->insert("{$wpdb->prefix}visitor_activity_activity", [
			'date_created' => gmdate('Y-m-d H:i:s'),
			'visitor_id' => $visitor_id,
			'type' => $type,
			'data' => $data,
		]);

		$activity_id = $wpdb->insert_id;

		do_action('visitoractivity/events/after_activity_add', $visitor_id, $type, $data, $activity_id);

		return $activity_id;
	}

	public static function get_all($visitor) {
		global $wpdb;

		$query = "
			SELECT * FROM {$wpdb->prefix}visitor_activity_activity
			WHERE visitor_id = {$visitor}
			ORDER BY date_created DESC
		";

		return $wpdb->get_results($query, ARRAY_A);
	}

	public static function get_recent($visitor) {
		global $wpdb;

		$query = "
			SELECT * FROM {$wpdb->prefix}visitor_activity_activity
			WHERE visitor_id = {$visitor}
			ORDER BY date_created DESC
			LIMIT 3
		";

		return $wpdb->get_results($query, ARRAY_A);
	}

	public static function query_unexported_activity() {
		global $wpdb;

		$date_boundary = date('Y-m-d H:i:s', strtotime('-45 days'));

		$query = "
			SELECT activity.*, visitor.email_address
			FROM {$wpdb->prefix}visitor_activity_activity activity
			JOIN {$wpdb->prefix}visitor_activity_visitors visitor ON activity.visitor_id = visitor.id
			WHERE exported = 0
			AND visitor.email_address IS NOT NULL
			AND activity.date_created > '{$date_boundary}'
			ORDER BY activity.date_created DESC
			LIMIT 10
		";

		return $wpdb->get_results($query, ARRAY_A);
	}

	public static function gather_unexported_for_everyone() {
		global $wpdb;

		$query = "
			SELECT * FROM {$wpdb->prefix}visitor_activity_activity
			WHERE exported = 0
			ORDER BY date_created ASC
			LIMIT 0,30
		";

		$unsorted_unexported_activity = $wpdb->get_results($query, ARRAY_A);
		$unexported_activity = array();

		foreach ($unsorted_unexported_activity as $key => $item) {
			$item['data'] = json_decode(unserialize($item['data']), true);
			$unexported_activity[$item['visitor_id']][$item['type']][$item['id']] = $item;
		}

		foreach ( $unexported_activity as $visitor_id => $data ) {

			if ( empty($unexported_activity[$visitor_id]['visitor']) ) {
				$visitor = Visitor::get($visitor_id);
				$unexported_activity[$visitor_id]['_visitor'] = $visitor;
			}

			if ( !empty($unexported_activity[$visitor_id]['PageView']) ) {
				$unexported_activity[$visitor_id]['recent_page_views_message'] = '';
				foreach ( $unexported_activity[$visitor_id]['PageView'] as $data ) {
					$unexported_activity[$visitor_id]['recent_page_views_message'] .= 'Visited ' . $data['data']['url'] . " \n";

					// $wpdb->update("{$wpdb->prefix}visitor_activity_activity",
					// 	array('exported' => true),
					// 	array('id' => $data['id'])
					// );
				}
			}
		}

		return $unexported_activity;
	}

	public static function get_old_exported_activities() {
		global $wpdb;

		$last_month = date('Y-m-d H:i:s', strtotime('-45 days'));

		$query = "
			SELECT * FROM {$wpdb->prefix}visitor_activity_activity
			WHERE exported = 1
			AND date_created < '{$last_month}'
			ORDER BY date_created ASC
			LIMIT 0,5
		";

		$activities = $wpdb->get_results($query, ARRAY_A);

		return $activities;
	}

	public static function delete_old_exported_activities() {
		global $wpdb;

		$activities = self::get_old_exported_activities();

		foreach ( $activities as $activity ) {
			$wpdb->delete($wpdb->prefix . 'visitor_activity_activity', array(
				'id' => $activity['id']
			));
		}

		return $activities;
	}
}
