<?php
namespace BrandCo\Plugins\KWCommand;

class KWCommand {
	public $visitor;

	public static function find_contact($email) {

		if ( WP_ENV !== 'live' && !defined('KW_TEST_TOKEN') ) {
			return 'fakeuser';
		}

		$request = new KWCommandRequest('GET', KW_COMMAND_PLUGIN_ENDPOINT . '/v3/contacts', array(
			'filter' => base64_encode(json_encode(array(
				'filter' => array(
					array(
						'$should' => array(
							array(
								'emails.primary.email' => array(
									'like' => $email
								)
							)
						)
					)
				)
			)))
		));

		$response = $request->send_request();

		$found_contact_id = '';

		if ( !empty($response['data'][0]['id']) ) {
			$found_contact_id = $response['data'][0]['id'];
		}

		return $found_contact_id;
	}

	public static function create_contact($first_name, $last_name, $email_address, $phone_number = '') {

		if ( WP_ENV !== 'live' && !defined('KW_TEST_TOKEN') ) {
			return 'fakeuser';
		}

		$args = array();

		$args['name'] = array(
			'first' => sanitize_text_field($first_name),
			'last' => sanitize_text_field($last_name),
		);

		$args['emails'] = array(
			'primary' => array(
				'email' => sanitize_email($email_address),
				'label' => 'PERSONAL'
			)
		);

		$args['tags'] = array(
			array(
				'color' => 'blue',
				'label' => $_SERVER['HTTP_HOST'] . ' Website Lead'
			),
		);

		$args['contactTypes'] = array(
			'mark' => array(
				'LEAD'
			)
		);

		if ( $phone_number ) {

			try {
				$phone_number = self::sanitize_phone($phone_number);
			} catch (\Exception $e) {}

			if ( $phone_number ) {
				$args['phones'] = array(
					'primary' => array(
						'ISOPhoneNumber' => $phone_number,
						'label' => 'PERSONAL'
					)
				);
			}
		}

		$request = new KWCommandRequest('POST', KW_COMMAND_PLUGIN_ENDPOINT . '/v3/contacts', $args);
		$response = $request->send_request();
		$contact_id = '';

		if ( !empty($response['id']) ) {
			$contact_id = $response['id'];
		}

		return $contact_id;
	}

	public static function create_note($visitor, $title, $note) {
		$kw_contact_id = self::find_contact($visitor['email_address']);

		if ( !$kw_contact_id ) {
			$kw_contact_id = self::create_contact(
				$visitor['first_name'],
				$visitor['last_name'],
				$visitor['email_address'],
				$visitor['phone_number']
			);
		}

		if ( !$kw_contact_id ) {
			return;
		}

		if ( WP_ENV !== 'live' && !defined('KW_TEST_TOKEN') ) {
			return array('id' => 'fakenote');
		}

		$request = new KWCommandRequest('POST', KW_COMMAND_PLUGIN_ENDPOINT . '/v3/contacts/' . $kw_contact_id . '/notes', array(
			'title' => $title,
			'note' => $note
		));

		usleep(250);

		$response = $request->send_request();

		return $response;
	}

	public static function send_activity($visitor_id, $activity_type, $activity_data, $activity_id) {
		global $wpdb;

		if ( WP_ENV !== 'live' && !defined('KW_TEST_TOKEN') ) {
			return;
		}

		$visitor = Visitor::get($visitor_id);

		if ( empty($visitor['email_address']) ) {
			return;
		}

		$note = array();

		$activity_data = json_decode(unserialize($activity_data), true);

		if ( 'FormSubmission' == $activity_type ) {
			$message = self::build_form_submission_note($activity_data);
			$note = self::create_note($visitor, 'New Form Submission', $message);
		}

		if ( 'IDXFormSubmission' == $activity_type ) {
			$message = self::build_idx_form_submission_note($activity_data);
			$note = self::create_note($visitor, 'IDX Form Submission', $message);
		}

		if ( 'IDXListingView' == $activity_type ) {
			$message = self::build_idx_listing_page_viewed_note($activity_data);
			$note = self::create_note($visitor, 'Viewed A Listing', $message);
		}

		if ( 'PageView' == $activity_type ) {
			$message = self::build_note_for__PageView($activity_data);
			$note = self::create_note($visitor, 'Viewed A Page', $message);
		}

		if ( 'IDXSearch' == $activity_type ) {
			$message = self::build_note_for__IDXSearch($activity_data);
			$note = self::create_note($visitor, 'Searched For Listings', $message);
		}

		if ( 'IDXFavListing' == $activity_type ) {
			$message = self::build_note_for__IDXFavListing($activity_data);
			$note = self::create_note($visitor, 'Favorited IDX Listing', $message);
		}

		if ( !empty($note['id']) ) {

			$wpdb->update("{$wpdb->prefix}visitor_activity_activity",
				array('exported' => true),
				array('id' => $activity_id)
			);
		}

		return $note;
	}

	public static function sanitize_phone($phone) {
		$phoneUtil = \libphonenumber\PhoneNumberUtil::getInstance();
		$usNumberProto = $phoneUtil->parse($phone, "US");
		$formatted_phone = $phoneUtil->format($usNumberProto, \libphonenumber\PhoneNumberFormat::E164);
		return ( strlen($formatted_phone) == 12 ) ? $formatted_phone : '';
	}

	public static function build_form_submission_note($activity_data) {
		$message = "\n";

		if ( !empty($activity_data['entire_submission']) ) {
			$activity_data['entire_submission'] = str_replace('<br>', " \n", $activity_data['entire_submission']);
			$message .= $activity_data['entire_submission'] . " \n";
			$message .= 'Origin Plugin: ' . $activity_data['origin_plugin'];

			return $message;
		}


		if ( !empty($activity_data['elementor_form_submission']) ) {
			foreach ( $activity_data['elementor_form_submission'] as $key => $value ) {
			    $message .= "$key: $value \n";
			}

			return $message;
		}

		if ( !empty($activity_data['first_name']) ) {
			$message .= 'First Name: ' . $activity_data['first_name'] . " \n";
		}

		if ( !empty($activity_data['last_name']) ) {
			$message .= 'Last Name: ' . $activity_data['last_name'] . " \n";
		}

		if ( !empty($activity_data['email_address']) ) {
			$message .= 'Email: ' . $activity_data['email_address'] . " \n";
		}

		if ( !empty($activity_data['phone_number']) ) {
			$message .= 'Phone: ' . $activity_data['phone_number'] . " \n";
		}

		if ( !empty($activity_data['message']) ) {
			$message .= 'Message: ' . $activity_data['message'] . " \n";
		}

		return $message;
	}

	public static function build_idx_listing_page_viewed_note($activity_data) {
		$message = '';
		$listing = $activity_data['idx_listing_data'];
		$message .= $listing['address1'] . ' ' . $listing['address2'] . " \n";
		$message .= $listing['price'] . ' ' . $listing['bed'] . '/' . $listing['bath'] . ' MLS# ' . $listing['mlsNumber'] . " \n";
		$message .= $listing['url'];
		return $message;
	}

	public static function build_idx_form_submission_note($activity_data) {
		$message = '';

		$message .= 'Message: ' . $activity_data['content'] . " \n";
		$message .= ($activity_data['day']) ? 'Preferred Meeting Day: ' . $activity_data['day'] . " \n" : '';
		$message .= ($activity_data['time']) ? 'Preferred Meeting Time: ' . $activity_data['time'] . " \n" : '';
		$message .= $activity_data['address'] . " \n";
		$message .= $activity_data['link'] . " \n";

		$message .= $listing['url'];
		return $message;
	}

	public static function build_note_for__PageView($activity_data) {
		$message = $activity_data['url'];
		return $message;
	}

	public static function build_note_for__IDXSearch($activity_data) {
		$message = '';
		$search = $activity_data['search_data'];

		if ( !empty($search['keywords']) ) {
			$message .= $search['keywords'] . " \n";
		}

		if ( !empty($search['priceText']) ) {
			$message .= $search['priceText'] . " \n";
		}

		if ( !empty($search['bedsText']) ) {
			$message .= $search['bedsText'] . " \n";
		}

		if ( !empty($search['bathsText']) ) {
			$message .= $search['bathsText'] . " \n";
		}

		return $message;
	}

	public static function build_note_for__IDXFavListing($activity_data) {
		$message = '';
		$message .= $activity_data['address'] . " \n";
		$message .= $activity_data['link'] . " \n \n";
		$message .= 'From ' . $activity_data['plugin'];
		return $message;
	}

	public static function send_unexported_activity() {
		$unexportedActivity = Activity::query_unexported_activity();
		$responses = [];

		foreach ( $unexportedActivity as $activity ) {
			$responses[] = KWCommand::send_activity(
				$activity['visitor_id'],
				$activity['type'],
				$activity['data'],
				$activity['id']
			);
		}

		return [
			'unexportedActivity' => $unexportedActivity,
			'responses' => $responses,
		];
	}
}
