<?php
namespace BrandCo\Plugins\KWCommand;
use WP_REST_Server, WP_REST_Request;

class RestAPI {

	public static function register() {
		register_rest_route('kwcommand/v1', '/check-latest-plugin-info', array(
			'methods'  => WP_REST_Server::READABLE,
			'permission_callback' => '__return_true',
			'callback' => __CLASS__ . '::check_latest_plugin_info',
		));

		register_rest_route('kwcommand/v1', '/testing', array(
			'methods'  => WP_REST_Server::READABLE,
			'permission_callback' => '__return_true',
			'callback' => __CLASS__ . '::testing',
		));

		register_rest_route('kwcommand/v1', '/kw-api-ping', array(
			'methods'  => WP_REST_Server::READABLE,
			'permission_callback' => '__return_true',
			'callback' => __CLASS__ . '::kw_api_ping',
		));

		register_rest_route('kwcommand/v1', '/elementor_webhook', array(
			'methods'  => WP_REST_Server::CREATABLE,
			'permission_callback' => '__return_true',
			'callback' => __CLASS__ . '::elementor_webhook',
		));
	}

	public static function elementor_webhook(WP_REST_Request $request) {
		$params = $request->get_params();
		$visitor = Visitor::get();

		ElementorForms::update_user_with_posted_data($params, $visitor);

		return rest_ensure_response(array(
			'params' => $params,
		));
	}

	public static function kw_api_ping(WP_REST_Request $request) {
		$request = new KWCommandRequest('GET', KW_COMMAND_PLUGIN_ENDPOINT . '/v3/contacts');
		$response = $request->send_request();

		return rest_ensure_response(array(
			'request' => $request,
			'response' => $response,
		));
	}

	public static function check_latest_plugin_info(WP_REST_Request $request) {
		$response = wp_remote_get('https://hellobrandco.github.io/kw-command-plugin/plugin-info.json');

		return rest_ensure_response(array(
			'response' => $response,
		));
	}

	public static function testing(WP_REST_Request $request) {
		$cookie = Cookie::get();
		$visitor = Visitor::get();
		$command = KWCommand::find_contact($visitor['email_address']);
		$activity = Activity::get_recent($visitor['id']);
		$unexported = KWCommand::send_unexported_activity();

		return rest_ensure_response(array(
			'cookie' => $cookie,
			'visitor' => $visitor,
			'command' => $command,
			'activity' => $activity,
			'version' => KW_COMMAND_PLUGIN_VERSION,
			'api' => KW_COMMAND_PLUGIN_ENDPOINT,
			'last_token' => get_option('kw_command_settings_last_refresh_token'),
			'recentUnexported' => $unexported,
		));
	}
}
